<?php
/***************************************************************
*  Copyright notice
*
*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * patch
 * Include file extending db_list.inc for use with the web_layout module
 *
 * $Id$
 *
 * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
 * @author	Franz Holzinger <franz@ttproducts.de>
 */



/**
 * Child class for the Web > Page module
 *
 * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
 * @package TYPO3
 * @subpackage patch1822
 */
class ux_tx_cms_layout extends tx_cms_layout {
	var $externalTables = array();			// Array of tables to be listed by the Web > Page module in addition to the default tables.

	/**
	 * Adds the code of a single table
	 *
	 * @param	string		Table name
	 * @param	integer		Current page id
	 * @return	string		HTML for listing.
	 */
	function getTable ($table,$id)	{

			// Load full table definition:
		t3lib_div::loadTCA($table);

		if (isset($this->externalTables[$table]))	{
			return $this->getExternalTables($id, $table);
		} else {
				// Branch out based on table name:
				// Notice: Most of these tables belongs to other extensions than 'cms'. Each of these tables can be rendered only if the extensions they belong to is loaded.
			switch($table)	{
				case 'pages':
					return $this->getTable_pages($id);
				break;
				case 'tt_content':
					return $this->getTable_tt_content($id);
				break;
				case 'fe_users':
					return $this->getTable_fe_users($id);
				break;
				case 'sys_note':
					return $this->getTable_sys_note($id);
				break;
				case 'tt_board':
					return $this->getTable_tt_board($id);
				break;
				case 'tt_address':
					return $this->getTable_tt_address($id);
				break;
				case 'tt_links':
					return $this->getTable_tt_links($id);
				break;
				case 'tt_guest':
					return $this->getTable_tt_guest($id);
				break;
				case 'tt_news':
					return $this->getTable_tt_news($id);
				break;
				case 'tt_calender':
					return $this->getTable_tt_calender($id);
				break;
				case 'tt_products':
					return $this->getTable_tt_products($id);
				break;
			}
		}
	}

	/**
	 * Renders an external table from page id
	 *
	 * @param	integer		Page id
	 * @param	string		name of the table
	 * @return	string		HTML for the listing
	 */
	function getExternalTables ($id, $table)	{

		$type = $GLOBALS['SOBE']->MOD_SETTINGS[$table];
		if (!isset($type)) {
			$type = 0;
		}

		$userLang = $GLOBALS['BE_USER']->uc['lang'];
		$fList = $this->externalTables[$table][$type]['fList'];	// eg. "name;title;email;company,image"
									// the columns are separeted by comma ','.
									// Values separated by semicolon ';' are shown in the same column.
		if (
			isset($this->externalTables[$table]['langArray']) &&
			is_array($this->externalTables[$table]['langArray']) &&
			isset($this->externalTables[$table]['langArray'][$userLang]) &&
			is_array($this->externalTables[$table]['langArray'][$userLang])
		)	{
			// add language fields before the English fields if found
			$fListArray = t3lib_div::trimExplode(',',$fList);
			if (is_array($fListArray))	{
				foreach ($this->externalTables[$table]['langArray'][$userLang] as $field => $langField)	{
					$k = array_search($field,$fListArray);
					if ($k !== FALSE)	{
						$fListArray[$k] = $langField . ',' . $field;
					}
				}
				$fList = implode(',',$fListArray);
			}
			unset($this->externalTables[$table]['langArray']);
		}

		$icon = $this->externalTables[$table][$type]['icon'];
		$addWhere = $this->externalTables[$table][$type]['addWhere'];
			// Create listing
		$out = $this->makeOrdinaryList($table, $id, $fList, $icon, $addWhere);
		return $out;
	}

	/**
	 * Renders shopping elements from the tt_products table from page id
	 * NOTICE: Requires the tt_products extension to be loaded.
	 *
	 * @param	integer		Page id
	 * @return	string		HTML for the listing
	 */
	function getTable_tt_products ($id)	{

		$type = $GLOBALS['SOBE']->MOD_SETTINGS['tt_products'];
		switch($type)	{
			case 'ext':
				$fList = 'title;ean;itemnumber;price;price2;tax,inStock;weight,color;color2;color3;size;size2;size3;description;gradings,image,note';
			break;
			default:
				$fList = 'title,ean,itemnumber,price,category,image';
			break;
		}
		$icon=1;
		$out = $this->makeOrdinaryList('tt_products',$id, $fList, 1);
		return $out;
	}

}



if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/patch1822/xclass/class.user_cms_layout.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/patch1822/xclass/class.user_cms_layout.php']);
}
?>
